Application Programming Interface Reference
===========================================

Core
----

.. automodule:: biblicus.corpus
   :members:
   :undoc-members:

.. automodule:: biblicus.knowledge_base
   :members:
   :undoc-members:

.. automodule:: biblicus.models
   :members:
   :undoc-members:

.. automodule:: biblicus.retrieval
   :members:
   :undoc-members:

.. automodule:: biblicus.context
   :members:
   :undoc-members:

.. automodule:: biblicus.evaluation
   :members:
   :undoc-members:

Extraction
----------

.. automodule:: biblicus.extraction
   :members:
   :undoc-members:

.. automodule:: biblicus.extractors
   :members:
   :undoc-members:

Graph
-----

.. automodule:: biblicus.graph.extraction
   :members:
   :undoc-members:

.. automodule:: biblicus.graph.models
   :members:
   :undoc-members:

.. automodule:: biblicus.graph.neo4j
   :members:
   :undoc-members:

.. automodule:: biblicus.graph.extractors
   :members:
   :undoc-members:

Backends
--------

.. automodule:: biblicus.backends.scan
   :members:
   :undoc-members:

.. automodule:: biblicus.backends.sqlite_full_text_search
   :members:
   :undoc-members:
